@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: buildouthttp.py 115983 2010-08-28 06:52:14Z dobe $
+$Id: buildouthttp.py 115985 2010-08-28 07:08:32Z dobe $
 """
 
 import urllib2
@@ -32,7 +32,7 @@ def get_github_credentials():
     """returns the credentials for the local git installation by using
     git config"""
 
-    p = subprocess.Popen("gitx config github.token",
+    p = subprocess.Popen("git config github.token",
                          shell=True,
                          stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE)
